@@ -200,7 +200,7 @@ class Pandora:
 
 		reqUrl = BASE_URL_LID %( self.rid, self.lid, "createStation" )
 		
-		args = ( _inttime(), self.authToken, "mi"+musicId )
+		args = ( _inttime(), self.authToken, "mi"+musicId, "" )
 
 		req = xmlrpclib.dumps( args, "station.createStation" )
 		req = req.replace( "\n", "" )
